diff --git a/mscore/musescore.cpp b/mscore/musescore.cpp
index b3dbb4c65..5b8d06fe3 100644
--- a/mscore/musescore.cpp
+++ b/mscore/musescore.cpp
@@ -7378,6 +7378,24 @@ MuseScoreApplication* MuseScoreApplication::initApplication(int& argc, char** ar
       return app;
       }
 
+//---------------------------------------------------------
+//   setCustomConfigFolder
+//---------------------------------------------------------
+
+bool MuseScoreApplication::setCustomConfigFolder(const QString& path)
+      {
+      const QFileInfo pinfo(path);
+
+      if (pinfo.exists() && pinfo.isDir()) {
+            QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, path);
+            QSettings::setPath(QSettings::IniFormat, QSettings::SystemScope, path);
+            dataPath = path;
+            return true;
+            }
+
+      return false;
+      }
+
 //---------------------------------------------------------
 //   parseCommandLineArguments
 //---------------------------------------------------------
@@ -7538,12 +7556,7 @@ MuseScoreApplication::CommandLineParseResult MuseScoreApplication::parseCommandL
             QString path = parser.value("c");
             if (path.isEmpty())
                   parser.showHelp(EXIT_FAILURE);
-            QDir dir;
-            if (dir.exists(path)) {
-                  QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, path);
-                  QSettings::setPath(QSettings::IniFormat, QSettings::SystemScope, path);
-                  dataPath = path;
-                  }
+            setCustomConfigFolder(path);
             }
       MScore::testMode = parser.isSet("t");
       if (parser.isSet("M")) {
diff --git a/mscore/musescore.h b/mscore/musescore.h
index 7922b63f2..2d02e352d 100644
--- a/mscore/musescore.h
+++ b/mscore/musescore.h
@@ -170,6 +170,8 @@ class MuseScoreApplication : public QtSingleApplication {
             };
       static CommandLineParseResult parseCommandLineArguments(MuseScoreApplication* app);
       static MuseScoreApplication* initApplication(int& argc, char** argv);
+
+      static bool setCustomConfigFolder(const QString& path);
       };
 
 
diff --git a/mtest/mscore/workspaces/tst_workspaces.cpp b/mtest/mscore/workspaces/tst_workspaces.cpp
index ef3377b74..2b1784cc0 100644
--- a/mtest/mscore/workspaces/tst_workspaces.cpp
+++ b/mtest/mscore/workspaces/tst_workspaces.cpp
@@ -79,6 +79,8 @@ void TestWorkspaces::initTestCase()
       {
       qputenv("QML_DISABLE_DISK_CACHE", "true");
       qSetMessagePattern("%{function}: %{message}");
+      // Force INI settings format to store settings in a temporary directory
+      QSettings::setDefaultFormat(QSettings::IniFormat);
       MScore::noGui = true;
       MScore::testMode = true;
       initMuseScoreResources();
@@ -90,7 +92,7 @@ void TestWorkspaces::initTestCase()
 
 void TestWorkspaces::initMuseScore()
       {
-      Ms::dataPath = tmpDataDir->path();
+      MuseScoreApplication::setCustomConfigFolder(tmpDataDir->path());
       QStringList temp;
       MuseScore::init(temp);
       WorkspacesManager::initCurrentWorkspace();
